==> Netzob-1.1.dev0.tar.gz: Netzob-1.1.dev0/src/netzob/release.py <==
# -*- coding: utf-8 -*-

#+---------------------------------------------------------------------------+
#|          01001110 01100101 01110100 01111010 01101111 01100010            |
#|                                                                           |
#|               Netzob : Inferring communication protocols                  |
#+---------------------------------------------------------------------------+
#| Copyright (C) 2011-2016 Georges Bossert and Frédéric Guihéry              |
#| This program is free software: you can redistribute it and/or modify      |
#| it under the terms of the GNU General Public License as published by      |
#| the Free Software Foundation, either version 3 of the License, or         |
#| (at your option) any later version.                                       |
#|                                                                           |
#| This program is distributed in the hope that it will be useful,           |
#| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
#| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              |
#| GNU General Public License for more details.                              |
#|                                                                           |
#| You should have received a copy of the GNU General Public License         |
#| along with this program. If not, see <http://www.gnu.org/licenses/>.      |
#+---------------------------------------------------------------------------+
#| @url      : http://www.netzob.org                                         |
#| @contact  : contact@netzob.org                                            |
#| @sponsors : Amossys, http://www.amossys.fr                                |
#|             Supélec, http://www.rennes.supelec.fr/ren/rd/cidre/           |
#+---------------------------------------------------------------------------+

#+---------------------------------------------------------------------------+
#| Official name of the project : Netzob
#+---------------------------------------------------------------------------+
name = "Netzob"

#+---------------------------------------------------------------------------+
#| Official name of the application
#+---------------------------------------------------------------------------+
appname = name

#+---------------------------------------------------------------------------+
#| Current OFFICIAL version of the application
#|    the version number must be changed during the last commit before
#|    the tag release.
#|    Development version has version number increased and is
#|    postfixed by ~git
#+---------------------------------------------------------------------------+
version = "1.1.dev0"
versionName = "Unnamed"

#+---------------------------------------------------------------------------+
#| Copyright mentions
#+---------------------------------------------------------------------------+
copyright = "Copyright (C) 2011-2017 Georges Bossert and Frédéric Guihéry"

#+---------------------------------------------------------------------------+
#| Description of the application
#+---------------------------------------------------------------------------+
description = "Reverse Engineering communication protocols"

#+---------------------------------------------------------------------------+
#| Platforms on which the application can be executed
#+---------------------------------------------------------------------------+
platforms = "Linux_x86, Linux_x64"

#+---------------------------------------------------------------------------+
#| Authors names
#+---------------------------------------------------------------------------+
author = "Georges Bossert, Frédéric Guihéry"

#+---------------------------------------------------------------------------+
#| Contributor names
#+---------------------------------------------------------------------------+
contributors = ["Georges Bossert <gbossert@miskin.fr>",
                "Frédéric Guihéry <frederic.guihery@amossys.fr>",
                "Olivier Tétard <olivier.tetard@amossys.fr>",
                "Goulven Guiheux <goulven.guiheux@amossys.fr>",
                "Maxime Olivier <maxime@miskin.fr>",
                "Alexandre Pigné <alex@freesenses.net>",
                "Franck Roland <franck.l.roland@gmail.com>",
                "Fabien André <fabien.andre@insa-rennes.fr>",
                "Quentin Heyler <quentin.heyler@etudiant.univ-rennes1.fr>",
                "Benjamin Dufour <benjamin.dufour@amossys.fr>",
                "Giuseppe Massaro <n3mes1s.oxoo@gmail.com>",
                "Timo Juhani <timo.lindfors@iki.fi>",
                "winnie",
                "Remy Delion",
                "Bertus Kruger",
                "Eric asselin",
                "Tammo Krueger"                
                ]

#+---------------------------------------------------------------------------+
#| Email to contact authors
#+---------------------------------------------------------------------------+
author_email = "contact@netzob.org"

#+---------------------------------------------------------------------------+
#| Official website of the application
#+---------------------------------------------------------------------------+
url = "http://www.netzob.org"

#+---------------------------------------------------------------------------+
#| Official url to download the application
#+---------------------------------------------------------------------------+
download_url = "https://github.com/netzob/netzob"

#+---------------------------------------------------------------------------+
#| Translators
#+---------------------------------------------------------------------------+
translator_credits = ""

#+---------------------------------------------------------------------------+
#| Keywords to describe the application
#+---------------------------------------------------------------------------+
keywords = ["Protocol", "Inference", "Networking", "Reverse Engineering", "Fuzzing", "Security"]

#+---------------------------------------------------------------------------+
#| Long description
#| <!> Do not use it anymore
#+---------------------------------------------------------------------------+
"""@deprecated: the official long description is now the full README.rst file"""
long_description = ""

#+---------------------------------------------------------------------------+
#| License used to publish the tool
#+---------------------------------------------------------------------------+
licenseName = "GPLv3"
license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""

==> Netzob-2.0.0.tar.gz: Netzob-2.0.0/src/netzob/release.py <==
# -*- coding: utf-8 -*-

#+---------------------------------------------------------------------------+
#|          01001110 01100101 01110100 01111010 01101111 01100010            |
#|                                                                           |
#|               Netzob : Inferring communication protocols                  |
#+---------------------------------------------------------------------------+
#| Copyright (C) 2011-2017 Georges Bossert and Frédéric Guihéry              |
#| This program is free software: you can redistribute it and/or modify      |
#| it under the terms of the GNU General Public License as published by      |
#| the Free Software Foundation, either version 3 of the License, or         |
#| (at your option) any later version.                                       |
#|                                                                           |
#| This program is distributed in the hope that it will be useful,           |
#| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
#| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              |
#| GNU General Public License for more details.                              |
#|                                                                           |
#| You should have received a copy of the GNU General Public License         |
#| along with this program. If not, see <http://www.gnu.org/licenses/>.      |
#+---------------------------------------------------------------------------+
#| @url      : http://www.netzob.org                                         |
#| @contact  : contact@netzob.org                                            |
#| @sponsors : Amossys, http://www.amossys.fr                                |
#|             Supélec, http://www.rennes.supelec.fr/ren/rd/cidre/           |
#+---------------------------------------------------------------------------+

#+---------------------------------------------------------------------------+
#| Official name of the project : Netzob
#+---------------------------------------------------------------------------+
name = "Netzob"

#+---------------------------------------------------------------------------+
#| Official name of the application
#+---------------------------------------------------------------------------+
appname = name

#+---------------------------------------------------------------------------+
#| Current OFFICIAL version of the application
#|    the version number must be changed during the last commit before
#|    the tag release.
#|    Development version has version number increased and is
#|    postfixed by .dev0
#+---------------------------------------------------------------------------+
version = "2.0.0"
versionName = "ClimbingSquirrel"

#+---------------------------------------------------------------------------+
#| Copyright mentions
#+---------------------------------------------------------------------------+
copyright = "Copyright (C) 2011-2022 Georges Bossert and Frédéric Guihéry"

#+---------------------------------------------------------------------------+
#| Description of the application
#+---------------------------------------------------------------------------+
description = "Protocol Reverse Engineering, Modeling and Fuzzing"

#+---------------------------------------------------------------------------+
#| Platforms on which the application can be executed
#+---------------------------------------------------------------------------+
platforms = "Linux_x86, Linux_x64"

#+---------------------------------------------------------------------------+
#| Authors names
#+---------------------------------------------------------------------------+
author = "Georges Bossert, Frédéric Guihéry"

#+---------------------------------------------------------------------------+
#| Contributor names
#+---------------------------------------------------------------------------+
contributors = [
    "Georges Bossert <gbossert@miskin.fr>",
    "Frédéric Guihéry <frederic.guihery@amossys.fr>",
    "Olivier Tétard <olivier.tetard@amossys.fr>",
    "Goulven Guiheux <goulven.guiheux@amossys.fr>",
    "Maxime Olivier <maxime@miskin.fr>",
    "Alexandre Pigné <alex@freesenses.net>",
    "Franck Roland <franck.l.roland@gmail.com>",
    "Fabien André <fabien.andre@insa-rennes.fr>",
    "Quentin Heyler <quentin.heyler@etudiant.univ-rennes1.fr>",
    "Benjamin Dufour <benjamin.dufour@amossys.fr>",
    "Giuseppe Massaro <n3mes1s.oxoo@gmail.com>",
    "Timo Juhani <timo.lindfors@iki.fi>", "winnie", "Remy Delion",
    "Bertus Kruger", "Eric asselin", "Tammo Krueger"
]

#+---------------------------------------------------------------------------+
#| Official website of the application
#+---------------------------------------------------------------------------+
url = "https://github.com/netzob/netzob"

#+---------------------------------------------------------------------------+
#| Official url to download the application
#+---------------------------------------------------------------------------+
download_url = "https://github.com/netzob/netzob"

#+---------------------------------------------------------------------------+
#| Translators
#+---------------------------------------------------------------------------+
translator_credits = ""

#+---------------------------------------------------------------------------+
#| Keywords to describe the application
#+---------------------------------------------------------------------------+
keywords = [
    "Protocol", "Inference", "Networking", "Reverse Engineering", "Fuzzing",
    "Security"
]

#+---------------------------------------------------------------------------+
#| Long description
#| <!> Do not use it anymore
#+---------------------------------------------------------------------------+
"""@deprecated: the official long description is now the full README.rst file"""
long_description = ""

#+---------------------------------------------------------------------------+
#| License used to publish the tool
#+---------------------------------------------------------------------------+
licenseName = "GPLv3"
license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""
